@@ -44,7 +44,7 @@ DocumentJob::DocumentJob()
     : KCompositeJob(nullptr)
     , d(new DocumentJobPrivate)
 {
-    auto *delegate = new KDialogJobUiDelegate;
+    auto delegate = new KDialogJobUiDelegate;
     delegate->setWindow(qApp->activeWindow());
     delegate->setAutoErrorHandlingEnabled(true);
     setUiDelegate(delegate);
@@ -82,8 +82,12 @@ bool DocumentJob::checkDocumentEditor()
 
 void ThreadedDocumentJob::doStart()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QFuture<void> future = QtConcurrent::run(this, &ThreadedDocumentJob::threadedStart);
-    auto *watcher = new QFutureWatcher<void>(this);
+#else
+    QFuture<void> future = QtConcurrent::run(&ThreadedDocumentJob::threadedStart, this);
+#endif
+    auto watcher = new QFutureWatcher<void>(this);
     connect(watcher, SIGNAL(finished()), SLOT(emitResult()));
     watcher->setFuture(future);
 }
