@@ -31,14 +31,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // KF
 
 // Qt
-#include <QUrl>
 
 namespace Gwenview
 {
 //// RasterImageViewAdapter ////
 struct RasterImageViewAdapterPrivate {
-    RasterImageViewAdapter *q;
-    RasterImageView *mView;
+    RasterImageViewAdapter *q = nullptr;
+    RasterImageView *mView = nullptr;
 };
 
 RasterImageViewAdapter::RasterImageViewAdapter()
