@@ -42,6 +42,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KIconLoader>
 #include <KPixmapSequence>
 #include <KUrlMimeData>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <KPixmapSequenceLoader>
+#endif
 
 // Local
 #include "abstractdocumentinfoprovider.h"
@@ -60,7 +63,7 @@ namespace Gwenview
 {
 #undef ENABLE_LOG
 #undef LOG
-//#define ENABLE_LOG
+// #define ENABLE_LOG
 #ifdef ENABLE_LOG
 #define LOG(x) // qCDebug(GWENVIEW_LIB_LOG) << x
 #else
@@ -196,7 +199,11 @@ struct ThumbnailViewPrivate {
 
     void setupBusyAnimation()
     {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         mBusySequence = KIconLoader::global()->loadPixmapSequence(QStringLiteral("process-working"), 22);
+#else
+        mBusySequence = KPixmapSequenceLoader::load(QStringLiteral("process-working"), 22);
+#endif
         mBusyAnimationTimeLine = new QTimeLine(100 * mBusySequence.frameCount(), q);
         mBusyAnimationTimeLine->setEasingCurve(QEasingCurve::Linear);
         mBusyAnimationTimeLine->setEndFrame(mBusySequence.frameCount() - 1);
